Struct style::values::specified::text::TextOverflow
[−]
[src]
pub struct TextOverflow {
pub first: TextOverflowSide,
pub second: Option<TextOverflowSide>,
}text-overflow. Specifies rendering when inline content overflows its line box edge.
Fields
first: TextOverflowSide
First value. Applies to end line box edge if no second is supplied; line-left edge otherwise.
second: Option<TextOverflowSide>
Second value. Applies to the line-right edge if supplied.